@@ -2,17 +2,12 @@
 // Copyright © 2020 The developers of linux-support. See the COPYRIGHT file in the top-level directory of this distribution and at https://raw.githubusercontent.com/lemonrock/linux-support/master/COPYRIGHT.
 
 
-object_name!
-(
-	ObjectName16,
-	u8,
-	15,
-	/// A Linux object name, used for Commands, Processes, Threads, NetworkInterfaces, BPF maps and BPF programs.
-	///
-	/// Relies on the fact that the following are all the same length:-
-	///
-	/// * `TASK_COMM_LEN`.
-	/// * `BPF_OBJ_NAME_LEN`.
-	/// * `IFNAMSIZ`.
-	/// * `IF_NAMESIZE`.
-);
+/// A Linux object name, used for Commands, Processes, Threads, NetworkInterfaces, BPF maps and BPF programs.
+///
+/// Relies on the fact that the following are all the same length:-
+///
+/// * `TASK_COMM_LEN`.
+/// * `BPF_OBJ_NAME_LEN`.
+/// * `IFNAMSIZ`.
+/// * `IF_NAMESIZE`.
+pub type ObjectName16 = ObjectName::<16>;
